# nc5ng-python-toplevel
Datum Transformation Library PyPi metapackage

Metapackage to install `nc5ng-python` components

Source of the package `nc5ng` on PyPi ([Link](https://pypi.org/project/nc5ng/))

Install the complete package distribution

`pip install nc5ng`
